# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Overview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_limited': 'bool',
        'environments': 'list[EnvironmentAndResources]'
    }

    attribute_map = {
        'account_limited': 'accountLimited',
        'environments': 'environments'
    }

    def __init__(self, account_limited=None, environments=None):  # noqa: E501
        """Overview - a model defined in Swagger"""  # noqa: E501
        self._account_limited = None
        self._environments = None
        self.discriminator = None
        if account_limited is not None:
            self.account_limited = account_limited
        if environments is not None:
            self.environments = environments

    @property
    def account_limited(self):
        """Gets the account_limited of this Overview.  # noqa: E501


        :return: The account_limited of this Overview.  # noqa: E501
        :rtype: bool
        """
        return self._account_limited

    @account_limited.setter
    def account_limited(self, account_limited):
        """Sets the account_limited of this Overview.


        :param account_limited: The account_limited of this Overview.  # noqa: E501
        :type: bool
        """

        self._account_limited = account_limited

    @property
    def environments(self):
        """Gets the environments of this Overview.  # noqa: E501


        :return: The environments of this Overview.  # noqa: E501
        :rtype: list[EnvironmentAndResources]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """Sets the environments of this Overview.


        :param environments: The environments of this Overview.  # noqa: E501
        :type: list[EnvironmentAndResources]
        """

        self._environments = environments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Overview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Overview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from zrok.environment.root import Root
import urllib3


def Overview(root: Root) -> str:
    if not root.IsEnabled():
        raise Exception("environment is not enabled; enable with 'zrok enable' first!")

    http = urllib3.PoolManager()
    apiEndpoint = root.ApiEndpoint().endpoint
    try:
        response = http.request(
            'GET',
            apiEndpoint + "/api/v1/overview",
            headers={
                "X-TOKEN": root.env.Token
            })
    except Exception as e:
        raise Exception("unable to get account overview", e)
    return response.data.decode('utf-8')



# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from zrok_api.api_client import ApiClient


class MetadataApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def configuration(self, **kwargs):  # noqa: E501
        """configuration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.configuration(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Configuration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.configuration_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.configuration_with_http_info(**kwargs)  # noqa: E501
            return data

    def configuration_with_http_info(self, **kwargs):  # noqa: E501
        """configuration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.configuration_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Configuration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method configuration" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/configuration', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Configuration',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_account_detail(self, **kwargs):  # noqa: E501
        """get_account_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_detail(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Environments
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_account_detail_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_account_detail_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_account_detail_with_http_info(self, **kwargs):  # noqa: E501
        """get_account_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_detail_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Environments
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_detail" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/detail/account', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Environments',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_account_metrics(self, **kwargs):  # noqa: E501
        """get_account_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_metrics(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str duration:
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_account_metrics_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_account_metrics_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_account_metrics_with_http_info(self, **kwargs):  # noqa: E501
        """get_account_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_metrics_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str duration:
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['duration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_metrics" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'duration' in params:
            query_params.append(('duration', params['duration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/metrics/account', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Metrics',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_environment_detail(self, env_zid, **kwargs):  # noqa: E501
        """get_environment_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_environment_detail(env_zid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str env_zid: (required)
        :return: EnvironmentAndResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_environment_detail_with_http_info(env_zid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_environment_detail_with_http_info(env_zid, **kwargs)  # noqa: E501
            return data

    def get_environment_detail_with_http_info(self, env_zid, **kwargs):  # noqa: E501
        """get_environment_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_environment_detail_with_http_info(env_zid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str env_zid: (required)
        :return: EnvironmentAndResources
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['env_zid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_environment_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'env_zid' is set
        if ('env_zid' not in params or
                params['env_zid'] is None):
            raise ValueError("Missing the required parameter `env_zid` when calling `get_environment_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'env_zid' in params:
            path_params['envZId'] = params['env_zid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/detail/environment/{envZId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EnvironmentAndResources',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_environment_metrics(self, env_id, **kwargs):  # noqa: E501
        """get_environment_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_environment_metrics(env_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str env_id: (required)
        :param str duration:
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_environment_metrics_with_http_info(env_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_environment_metrics_with_http_info(env_id, **kwargs)  # noqa: E501
            return data

    def get_environment_metrics_with_http_info(self, env_id, **kwargs):  # noqa: E501
        """get_environment_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_environment_metrics_with_http_info(env_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str env_id: (required)
        :param str duration:
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['env_id', 'duration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_environment_metrics" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'env_id' is set
        if ('env_id' not in params or
                params['env_id'] is None):
            raise ValueError("Missing the required parameter `env_id` when calling `get_environment_metrics`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'env_id' in params:
            path_params['envId'] = params['env_id']  # noqa: E501

        query_params = []
        if 'duration' in params:
            query_params.append(('duration', params['duration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/metrics/environment/{envId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Metrics',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_frontend_detail(self, fe_id, **kwargs):  # noqa: E501
        """get_frontend_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_frontend_detail(fe_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int fe_id: (required)
        :return: Frontend
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_frontend_detail_with_http_info(fe_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_frontend_detail_with_http_info(fe_id, **kwargs)  # noqa: E501
            return data

    def get_frontend_detail_with_http_info(self, fe_id, **kwargs):  # noqa: E501
        """get_frontend_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_frontend_detail_with_http_info(fe_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int fe_id: (required)
        :return: Frontend
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fe_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_frontend_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'fe_id' is set
        if ('fe_id' not in params or
                params['fe_id'] is None):
            raise ValueError("Missing the required parameter `fe_id` when calling `get_frontend_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'fe_id' in params:
            path_params['feId'] = params['fe_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/detail/frontend/{feId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Frontend',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_share_detail(self, shr_token, **kwargs):  # noqa: E501
        """get_share_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_share_detail(shr_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shr_token: (required)
        :return: Share
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_share_detail_with_http_info(shr_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_share_detail_with_http_info(shr_token, **kwargs)  # noqa: E501
            return data

    def get_share_detail_with_http_info(self, shr_token, **kwargs):  # noqa: E501
        """get_share_detail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_share_detail_with_http_info(shr_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shr_token: (required)
        :return: Share
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shr_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_share_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shr_token' is set
        if ('shr_token' not in params or
                params['shr_token'] is None):
            raise ValueError("Missing the required parameter `shr_token` when calling `get_share_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shr_token' in params:
            path_params['shrToken'] = params['shr_token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/detail/share/{shrToken}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Share',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_share_metrics(self, shr_token, **kwargs):  # noqa: E501
        """get_share_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_share_metrics(shr_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shr_token: (required)
        :param str duration:
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_share_metrics_with_http_info(shr_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_share_metrics_with_http_info(shr_token, **kwargs)  # noqa: E501
            return data

    def get_share_metrics_with_http_info(self, shr_token, **kwargs):  # noqa: E501
        """get_share_metrics  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_share_metrics_with_http_info(shr_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shr_token: (required)
        :param str duration:
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shr_token', 'duration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_share_metrics" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shr_token' is set
        if ('shr_token' not in params or
                params['shr_token'] is None):
            raise ValueError("Missing the required parameter `shr_token` when calling `get_share_metrics`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shr_token' in params:
            path_params['shrToken'] = params['shr_token']  # noqa: E501

        query_params = []
        if 'duration' in params:
            query_params.append(('duration', params['duration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/metrics/share/{shrToken}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Metrics',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def overview(self, **kwargs):  # noqa: E501
        """overview  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.overview(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Overview
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.overview_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.overview_with_http_info(**kwargs)  # noqa: E501
            return data

    def overview_with_http_info(self, **kwargs):  # noqa: E501
        """overview  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.overview_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Overview
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method overview" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['key']  # noqa: E501

        return self.api_client.call_api(
            '/overview', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Overview',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def version(self, **kwargs):  # noqa: E501
        """version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.version_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.version_with_http_info(**kwargs)  # noqa: E501
            return data

    def version_with_http_info(self, **kwargs):  # noqa: E501
        """version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Version
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method version" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/zrok.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/version', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Version',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from pathlib import Path
import os


def rootDir() -> str:
    home = str(Path.home())
    return os.path.join(home, ".zrok")


def metadataFile() -> str:
    zrd = rootDir()
    return os.path.join(zrd, "metadata.json")


def configFile() -> str:
    zrd = rootDir()
    return os.path.join(zrd, "config.json")


def environmentFile() -> str:
    zrd = rootDir()
    return os.path.join(zrd, "environment.json")


def identitiesDir() -> str:
    zrd = rootDir()
    return os.path.join(zrd, "identities")


def identityFile(name: str) -> str:
    idd = identitiesDir()
    return os.path.join(idd, name + ".json")



# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Configuration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version': 'str',
        'tou_link': 'str',
        'invites_open': 'bool',
        'requires_invite_token': 'bool',
        'invite_token_contact': 'str',
        'password_requirements': 'PasswordRequirements'
    }

    attribute_map = {
        'version': 'version',
        'tou_link': 'touLink',
        'invites_open': 'invitesOpen',
        'requires_invite_token': 'requiresInviteToken',
        'invite_token_contact': 'inviteTokenContact',
        'password_requirements': 'passwordRequirements'
    }

    def __init__(self, version=None, tou_link=None, invites_open=None, requires_invite_token=None, invite_token_contact=None, password_requirements=None):  # noqa: E501
        """Configuration - a model defined in Swagger"""  # noqa: E501
        self._version = None
        self._tou_link = None
        self._invites_open = None
        self._requires_invite_token = None
        self._invite_token_contact = None
        self._password_requirements = None
        self.discriminator = None
        if version is not None:
            self.version = version
        if tou_link is not None:
            self.tou_link = tou_link
        if invites_open is not None:
            self.invites_open = invites_open
        if requires_invite_token is not None:
            self.requires_invite_token = requires_invite_token
        if invite_token_contact is not None:
            self.invite_token_contact = invite_token_contact
        if password_requirements is not None:
            self.password_requirements = password_requirements

    @property
    def version(self):
        """Gets the version of this Configuration.  # noqa: E501


        :return: The version of this Configuration.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Configuration.


        :param version: The version of this Configuration.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def tou_link(self):
        """Gets the tou_link of this Configuration.  # noqa: E501


        :return: The tou_link of this Configuration.  # noqa: E501
        :rtype: str
        """
        return self._tou_link

    @tou_link.setter
    def tou_link(self, tou_link):
        """Sets the tou_link of this Configuration.


        :param tou_link: The tou_link of this Configuration.  # noqa: E501
        :type: str
        """

        self._tou_link = tou_link

    @property
    def invites_open(self):
        """Gets the invites_open of this Configuration.  # noqa: E501


        :return: The invites_open of this Configuration.  # noqa: E501
        :rtype: bool
        """
        return self._invites_open

    @invites_open.setter
    def invites_open(self, invites_open):
        """Sets the invites_open of this Configuration.


        :param invites_open: The invites_open of this Configuration.  # noqa: E501
        :type: bool
        """

        self._invites_open = invites_open

    @property
    def requires_invite_token(self):
        """Gets the requires_invite_token of this Configuration.  # noqa: E501


        :return: The requires_invite_token of this Configuration.  # noqa: E501
        :rtype: bool
        """
        return self._requires_invite_token

    @requires_invite_token.setter
    def requires_invite_token(self, requires_invite_token):
        """Sets the requires_invite_token of this Configuration.


        :param requires_invite_token: The requires_invite_token of this Configuration.  # noqa: E501
        :type: bool
        """

        self._requires_invite_token = requires_invite_token

    @property
    def invite_token_contact(self):
        """Gets the invite_token_contact of this Configuration.  # noqa: E501


        :return: The invite_token_contact of this Configuration.  # noqa: E501
        :rtype: str
        """
        return self._invite_token_contact

    @invite_token_contact.setter
    def invite_token_contact(self, invite_token_contact):
        """Sets the invite_token_contact of this Configuration.


        :param invite_token_contact: The invite_token_contact of this Configuration.  # noqa: E501
        :type: str
        """

        self._invite_token_contact = invite_token_contact

    @property
    def password_requirements(self):
        """Gets the password_requirements of this Configuration.  # noqa: E501


        :return: The password_requirements of this Configuration.  # noqa: E501
        :rtype: PasswordRequirements
        """
        return self._password_requirements

    @password_requirements.setter
    def password_requirements(self, password_requirements):
        """Sets the password_requirements of this Configuration.


        :param password_requirements: The password_requirements of this Configuration.  # noqa: E501
        :type: PasswordRequirements
        """

        self._password_requirements = password_requirements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Configuration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Configuration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateFrontendRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'z_id': 'str',
        'url_template': 'str',
        'public_name': 'str',
        'permission_mode': 'str'
    }

    attribute_map = {
        'z_id': 'zId',
        'url_template': 'url_template',
        'public_name': 'public_name',
        'permission_mode': 'permissionMode'
    }

    def __init__(self, z_id=None, url_template=None, public_name=None, permission_mode=None):  # noqa: E501
        """CreateFrontendRequest - a model defined in Swagger"""  # noqa: E501
        self._z_id = None
        self._url_template = None
        self._public_name = None
        self._permission_mode = None
        self.discriminator = None
        if z_id is not None:
            self.z_id = z_id
        if url_template is not None:
            self.url_template = url_template
        if public_name is not None:
            self.public_name = public_name
        if permission_mode is not None:
            self.permission_mode = permission_mode

    @property
    def z_id(self):
        """Gets the z_id of this CreateFrontendRequest.  # noqa: E501


        :return: The z_id of this CreateFrontendRequest.  # noqa: E501
        :rtype: str
        """
        return self._z_id

    @z_id.setter
    def z_id(self, z_id):
        """Sets the z_id of this CreateFrontendRequest.


        :param z_id: The z_id of this CreateFrontendRequest.  # noqa: E501
        :type: str
        """

        self._z_id = z_id

    @property
    def url_template(self):
        """Gets the url_template of this CreateFrontendRequest.  # noqa: E501


        :return: The url_template of this CreateFrontendRequest.  # noqa: E501
        :rtype: str
        """
        return self._url_template

    @url_template.setter
    def url_template(self, url_template):
        """Sets the url_template of this CreateFrontendRequest.


        :param url_template: The url_template of this CreateFrontendRequest.  # noqa: E501
        :type: str
        """

        self._url_template = url_template

    @property
    def public_name(self):
        """Gets the public_name of this CreateFrontendRequest.  # noqa: E501


        :return: The public_name of this CreateFrontendRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_name

    @public_name.setter
    def public_name(self, public_name):
        """Sets the public_name of this CreateFrontendRequest.


        :param public_name: The public_name of this CreateFrontendRequest.  # noqa: E501
        :type: str
        """

        self._public_name = public_name

    @property
    def permission_mode(self):
        """Gets the permission_mode of this CreateFrontendRequest.  # noqa: E501


        :return: The permission_mode of this CreateFrontendRequest.  # noqa: E501
        :rtype: str
        """
        return self._permission_mode

    @permission_mode.setter
    def permission_mode(self, permission_mode):
        """Sets the permission_mode of this CreateFrontendRequest.


        :param permission_mode: The permission_mode of this CreateFrontendRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["open", "closed"]  # noqa: E501
        if permission_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `permission_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(permission_mode, allowed_values)
            )

        self._permission_mode = permission_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateFrontendRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateFrontendRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from zrok_api.api.account_api import AccountApi
from zrok_api.api.admin_api import AdminApi
from zrok_api.api.environment_api import EnvironmentApi
from zrok_api.api.metadata_api import MetadataApi
from zrok_api.api.share_api import ShareApi



# coding: utf-8

"""
    zrok

    zrok client access  # noqa: E501

    OpenAPI spec version: 0.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateShareRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shr_token': 'str',
        'backend_proxy_endpoint': 'str',
        'add_access_grants': 'list[str]',
        'remove_access_grants': 'list[str]'
    }

    attribute_map = {
        'shr_token': 'shrToken',
        'backend_proxy_endpoint': 'backendProxyEndpoint',
        'add_access_grants': 'addAccessGrants',
        'remove_access_grants': 'removeAccessGrants'
    }

    def __init__(self, shr_token=None, backend_proxy_endpoint=None, add_access_grants=None, remove_access_grants=None):  # noqa: E501
        """UpdateShareRequest - a model defined in Swagger"""  # noqa: E501
        self._shr_token = None
        self._backend_proxy_endpoint = None
        self._add_access_grants = None
        self._remove_access_grants = None
        self.discriminator = None
        if shr_token is not None:
            self.shr_token = shr_token
        if backend_proxy_endpoint is not None:
            self.backend_proxy_endpoint = backend_proxy_endpoint
        if add_access_grants is not None:
            self.add_access_grants = add_access_grants
        if remove_access_grants is not None:
            self.remove_access_grants = remove_access_grants

    @property
    def shr_token(self):
        """Gets the shr_token of this UpdateShareRequest.  # noqa: E501


        :return: The shr_token of this UpdateShareRequest.  # noqa: E501
        :rtype: str
        """
        return self._shr_token

    @shr_token.setter
    def shr_token(self, shr_token):
        """Sets the shr_token of this UpdateShareRequest.


        :param shr_token: The shr_token of this UpdateShareRequest.  # noqa: E501
        :type: str
        """

        self._shr_token = shr_token

    @property
    def backend_proxy_endpoint(self):
        """Gets the backend_proxy_endpoint of this UpdateShareRequest.  # noqa: E501


        :return: The backend_proxy_endpoint of this UpdateShareRequest.  # noqa: E501
        :rtype: str
        """
        return self._backend_proxy_endpoint

    @backend_proxy_endpoint.setter
    def backend_proxy_endpoint(self, backend_proxy_endpoint):
        """Sets the backend_proxy_endpoint of this UpdateShareRequest.


        :param backend_proxy_endpoint: The backend_proxy_endpoint of this UpdateShareRequest.  # noqa: E501
        :type: str
        """

        self._backend_proxy_endpoint = backend_proxy_endpoint

    @property
    def add_access_grants(self):
        """Gets the add_access_grants of this UpdateShareRequest.  # noqa: E501


        :return: The add_access_grants of this UpdateShareRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_access_grants

    @add_access_grants.setter
    def add_access_grants(self, add_access_grants):
        """Sets the add_access_grants of this UpdateShareRequest.


        :param add_access_grants: The add_access_grants of this UpdateShareRequest.  # noqa: E501
        :type: list[str]
        """

        self._add_access_grants = add_access_grants

    @property
    def remove_access_grants(self):
        """Gets the remove_access_grants of this UpdateShareRequest.  # noqa: E501


        :return: The remove_access_grants of this UpdateShareRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_access_grants

    @remove_access_grants.setter
    def remove_access_grants(self, remove_access_grants):
        """Sets the remove_access_grants of this UpdateShareRequest.


        :param remove_access_grants: The remove_access_grants of this UpdateShareRequest.  # noqa: E501
        :type: list[str]
        """

        self._remove_access_grants = remove_access_grants

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateShareRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateShareRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from zrok.environment.root import Root
from zrok_api.models import ShareRequest, UnshareRequest, AuthUser
from zrok_api.api import ShareApi
from zrok import model


class Share():
    root: Root
    request: model.ShareRequest
    share: model.Share

    def __init__(self, root: Root, request: model.ShareRequest):
        self.root = root
        self.request = request

    def __enter__(self) -> model.Share:
        self.share = CreateShare(root=self.root, request=self.request)
        return self.share

    def __exit__(self, exception_type, exception_value, exception_traceback):
        if not self.request.Reserved:
            DeleteShare(root=self.root, shr=self.share)


def CreateShare(root: Root, request: model.ShareRequest) -> model.Share:
    if not root.IsEnabled():
        raise Exception("environment is not enabled; enable with 'zrok enable' first!")

    match request.ShareMode:
        case model.PRIVATE_SHARE_MODE:
            out = __newPrivateShare(root, request)
        case model.PUBLIC_SHARE_MODE:
            out = __newPublicShare(root, request)
        case _:
            raise Exception("unknown share mode " + request.ShareMode)
    out.reserved = request.Reserved
    if request.Reserved:
        out.unique_name = request.UniqueName

    if len(request.BasicAuth) > 0:
        out.auth_scheme = model.AUTH_SCHEME_BASIC
        for pair in request.BasicAuth:
            tokens = pair.split(":")
            if len(tokens) == 2:
                out.auth_users.append(AuthUser(username=tokens[0].strip(), password=tokens[1].strip()))
            else:
                raise Exception("invalid username:password pair: " + pair)

    if request.OauthProvider != "":
        out.auth_scheme = model.AUTH_SCHEME_OAUTH

    try:
        zrok = root.Client()
    except Exception as e:
        raise Exception("error getting zrok client", e)
    try:
        res = ShareApi(zrok).share(body=out)
    except Exception as e:
        raise Exception("unable to create share", e)

    return model.Share(Token=res.shr_token,
                       FrontendEndpoints=res.frontend_proxy_endpoints)


def __newPrivateShare(root: Root, request: model.ShareRequest) -> ShareRequest:
    return ShareRequest(env_zid=root.env.ZitiIdentity,
                        share_mode=request.ShareMode,
                        backend_mode=request.BackendMode,
                        backend_proxy_endpoint=request.Target,
                        auth_scheme=model.AUTH_SCHEME_NONE,
                        permission_mode=request.PermissionMode,
                        access_grants=request.AccessGrants
                        )


def __newPublicShare(root: Root, request: model.ShareRequest) -> ShareRequest:
    ret = ShareRequest(env_zid=root.env.ZitiIdentity,
                       share_mode=request.ShareMode,
                       frontend_selection=request.Frontends,
                       backend_mode=request.BackendMode,
                       backend_proxy_endpoint=request.Target,
                       auth_scheme=model.AUTH_SCHEME_NONE,
                       oauth_email_domains=request.OauthEmailAddressPatterns,
                       oauth_authorization_check_interval=request.OauthAuthorizationCheckInterval,
                       permission_mode=request.PermissionMode,
                       access_grants=request.AccessGrants
                       )
    if request.OauthProvider != "":
        ret.oauth_provider = request.OauthProvider

    return ret


def DeleteShare(root: Root, shr: model.Share):
    req = UnshareRequest(env_zid=root.env.ZitiIdentity,
                         shr_token=shr.Token)

    try:
        zrok = root.Client()
    except Exception as e:
        raise Exception("error getting zrok client", e)

    try:
        ShareApi(zrok).unshare(body=req)
    except Exception as e:
        raise Exception("error deleting share", e)
